unit uPreferencesDlgUtils;

{$mode objfpc}{$H+}
{$ModeSwitch advancedrecords}

interface

uses
  StdCtrls, ExtCtrls, Controls;

resourcestring
  rsAudio =                'Audio';
  rsBrightness =           'Brightness:';
  rsColourBalance =        'Colour Balance';
  rsContrast =             'Contrast:';
  rsCoronaMonoscopeOscil = 'Corona,Monoscope,Oscilloscope,Spectrum';
  rsDisableDeinterlacing = 'Disable deinterlacing of interlaced videos';
  rsDisableScreensaverWh = 'Disable screensaver when playing';
  rsDisplay =              'Display';
  rsGeneral =              'General';
  rsHue =                  'Hue:';
  rsNormalLargeExtraLarg = 'Normal,Large,"Extra large"';
  rsPreferences =          'Preferences';
  rsResetToDefaults =      'Reset to Defaults';
  rsResizeTheWindowWhenA = 'Resize the window when a new video is loaded';
  rsSaturation =           'Saturation:';
  rsShowVisualEffectsWhe = 'Show visual effects when an audio file is played';
  rsTypeOfVisualisation =  'Type of visualisation:';
  rsUserDialogSetValuesA = 'User dialog set values as follows:';
  rsVideo =                'Video';
  rsVideoOrAudio =         'Video or Audio';
  rsVisualEffects =        'Visual Effects';
  rsVisualisationSize =    'Visualisation size:';

const
  Margin = 10;
  HalfMargin = Margin shr 1;

type

  TVisualisationSize = (vNormal, vLarge, vExtraLarge);

  TVisualisationKind = (vkCorona, vkMonoscope, vkOscilloscope, vkSpectrum);

  { TDisplaySettings }

  TDisplaySettings = record
    newVideoResize: Boolean;
    disableDeinterlacing: Boolean;
    disableScreenSaverBoth: Boolean;
    showVisualEffects: Boolean;
    visualisationKind: TVisualisationKind;
    visualisationSize: TVisualisationSize;
    brightness: Integer;
    contrast: Integer;
    saturation: Integer;
    hue: Integer;
    procedure Init(aNewVideoResize, aDisableInterlacing, aDisableScreenSaverBoth, aShowVisualEffects: Boolean;
                   aVisualisationKind: TVisualisationKind; aVisualisationSize: TVisualisationSize;
                   aBrightness, aContrast, aSaturation, aHue: Integer);
    procedure WriteToMemo(aMemo: TMemo);
  end;

  { TGroupPanel }

  TGroupPanel = class(TCustomControl)
  private
    FTitle: TLabel;
  protected
    procedure SetParent(NewParent: TWinControl); override;
  public
    constructor Create(aWinControl: TWinControl; const aCaption: TCaption); reintroduce;
    property Title: TLabel read FTitle;
  end;

implementation

uses
  sysutils, typinfo, Graphics;

{ TGroupPanel }

constructor TGroupPanel.Create(aWinControl: TWinControl; const aCaption: TCaption);
begin
  inherited Create(aWinControl);
  BorderSpacing.Around:=Margin;
  with GetControlClassDefaultSize do
    SetInitialBounds(Margin, Margin, cx, cy);
  AnchorSideLeft.Control:=Parent;
  FTitle:=TLabel.Create(Self);
  FTitle.AnchorSideLeft.Control:=Self;
  FTitle.AnchorSideTop.Control:=Self;
  FTitle.BorderSpacing.Left:=HalfMargin;
  FTitle.BorderSpacing.Top:=HalfMargin;
  FTitle.Caption:=aCaption;
  FTitle.Font.Style:=[fsBold];
  FTitle.Parent:=Self;
  AutoSize:=True;
end;

procedure TGroupPanel.SetParent(NewParent: TWinControl);
begin
  inherited SetParent(NewParent);
  if Assigned(NewParent) then
    Constraints.MinWidth:=Margin shl 1 + Canvas.TextWidth(Caption);
end;

{ TDisplaySettings }

procedure TDisplaySettings.Init(aNewVideoResize, aDisableInterlacing,
  aDisableScreenSaverBoth, aShowVisualEffects: Boolean;
  aVisualisationKind: TVisualisationKind;
  aVisualisationSize: TVisualisationSize; aBrightness, aContrast, aSaturation,
  aHue: Integer);
begin
  newVideoResize:=aNewVideoResize;
  disableDeinterlacing:=aDisableInterlacing;
  disableScreenSaverBoth:=aDisableScreenSaverBoth;
  showVisualEffects:=aShowVisualEffects;
  visualisationKind:=aVisualisationKind;
  visualisationSize:=aVisualisationSize;
  brightness:=aBrightness;
  contrast:=aContrast;
  saturation:=aSaturation;
  hue:=aHue;
end;

procedure TDisplaySettings.WriteToMemo(aMemo: TMemo);
begin
  if Assigned(aMemo) then
  with aMemo.Lines do begin
    Clear;
    Add(rsUserDialogSetValuesA);
    Add('  newVideoResize=' + BoolToStr(newVideoResize, True));
    Add('  disableInterlacing=' + BoolToStr(disableDeinterlacing, True));
    Add('  disableScreenSaverBoth=' + BoolToStr(disableScreenSaverBoth, True));
    Add('  showVisualEffects=' + BoolToStr(showVisualEffects, True));
    Add('  visualisationKind=' + GetEnumName(TypeInfo(TVisualisationKind), Ord(visualisationKind)));
    Add('  visualisationSize=' + GetEnumName(TypeInfo(TVisualisationSize), Ord(visualisationSize)));
    Add('  brightness=' + IntToStr(brightness));
    Add('  contrast=' + IntToStr(contrast));
    Add('  saturation=' + IntToStr(saturation));
    Add('  hue=' + IntToStr(hue));
  end;
end;

end.

